@@ -1,5 +1,5 @@
 --[[
-Copyright (c) 2017-2018, Vsevolod Stakhov <vsevolod@highsecure.ru>
+Copyright (c) 2022, Vsevolod Stakhov <vsevolod@rspamd.com>
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -40,11 +40,10 @@ local default_prefix = 'RR:' -- Rspamd Reputation
 
 local tanh = math.tanh or rspamd_util.tanh
 
-local reject_threshold = rspamd_config:get_action('reject') or 10.0
-
 -- Get reputation from ham/spam/probable hits
 local function generic_reputation_calc(token, rule, mult, task)
   local cfg = rule.selector.config or E
+  local reject_threshold = task:get_metric_score()[2] or 10.0
 
   if cfg.score_calc_func then
     return cfg.score_calc_func(rule, token, mult)
@@ -64,20 +63,35 @@ local function generic_reputation_calc(token, rule, mult, task)
   -- Apply function tanh(x / reject_score * atanh(0.95) - atanh(0.5))
   --                                        1.83178       0.5493
   local score = tanh(avg_score / reject_threshold * 1.83178 - 0.5493) * mult
-  lua_util.debugm(N, task, "got generic average score %s -> %s for rule %s",
-      avg_score, score, rule.symbol)
+  lua_util.debugm(N, task, "got generic average score %s (reject threshold=%s, mult=%s) -> %s for rule %s",
+      avg_score, reject_threshold, mult, score, rule.symbol)
   return score
 end
 
 local function add_symbol_score(task, rule, mult, params)
-  if not params then params = {tostring(mult)};
-
+  if not params then
+    params = {tostring(mult)}
   end
+
   if rule.selector.config.split_symbols then
+    local sym_spam = rule.symbol .. '_SPAM'
+    local sym_ham = rule.symbol .. '_HAM'
+    if not rule.static_symbols then
+      rule.static_symbols = {}
+      rule.static_symbols.ham = rspamd_config:get_symbol(sym_ham)
+      rule.static_symbols.spam = rspamd_config:get_symbol(sym_spam)
+    end
     if mult >= 0 then
-      task:insert_result(rule.symbol .. '_SPAM', mult, params)
+      task:insert_result(sym_spam, mult, params)
     else
-      task:insert_result(rule.symbol .. '_HAM', mult, params)
+      -- Avoid multiplication of negative the `mult` by negative static score of the
+      -- ham symbol
+      if rule.static_symbols.ham and rule.static_symbols.ham.score then
+        if rule.static_symbols.ham.score < 0 then
+          mult = math.abs(mult)
+        end
+      end
+      task:insert_result(sym_ham, mult, params)
     end
   else
     task:insert_result(rule.symbol, mult, params)
@@ -157,39 +171,53 @@ end
 local function dkim_reputation_filter(task, rule)
   local requests = gen_dkim_queries(task, rule)
   local results = {}
-  local nchecked = 0
+  local dkim_tlds = lua_util.keys(requests)
+  local requests_left = #dkim_tlds
   local rep_accepted = 0.0
-  local rep_rejected = 0.0
 
   lua_util.debugm(N, task, 'dkim reputation tokens: %s', requests)
 
   local function tokens_cb(err, token, values)
-    nchecked = nchecked + 1
+    requests_left = requests_left - 1
 
     if values then
       results[token] = values
     end
 
-    if nchecked == #requests then
+    if requests_left == 0 then
       for k,v in pairs(results) do
-        if requests[k] == 'a' then
-          rep_accepted = rep_accepted + generic_reputation_calc(v, rule, 1.0, task)
-        elseif requests[k] == 'r' then
-          rep_rejected = rep_rejected + generic_reputation_calc(v, rule, 1.0, task)
+        -- `k` in results is a prefixed and suffixed tld, so we need to look through
+        -- all requests to find any request with the matching tld
+        local sel_tld
+        for _,tld in ipairs(dkim_tlds) do
+          if k:find(tld, 1, true) then
+            sel_tld = tld
+            break
+          end
+        end
+
+        if sel_tld and requests[sel_tld] then
+          if requests[sel_tld] == 'a' then
+            rep_accepted = rep_accepted + generic_reputation_calc(v, rule, 1.0, task)
+          end
+        else
+          rspamd_logger.warnx(task, "cannot find the requested tld for a request: %s (%s tlds noticed)",
+              k, dkim_tlds)
         end
       end
 
       -- Set local reputation symbol
-      if rep_accepted > 0 or rep_rejected > 0 then
-        if rep_accepted > rep_rejected then
-          add_symbol_score(task, rule, -(rep_accepted - rep_rejected))
-        else
-          add_symbol_score(task, rule, (rep_rejected - rep_accepted))
-        end
+      local rep_accepted_abs = math.abs(rep_accepted or 0)
+      lua_util.debugm(N, task, "dkim reputation accepted: %s",
+          rep_accepted_abs)
+      if rep_accepted_abs then
+        local final_rep = rep_accepted
+        if rep_accepted > 1.0 then final_rep = 1.0 end
+        if rep_accepted < -1.0 then final_rep = -1.0 end
+        add_symbol_score(task, rule, final_rep)
 
         -- Store results for future DKIM results adjustments
         task:get_mempool():set_variable("dkim_reputation_accept", tostring(rep_accepted))
-        task:get_mempool():set_variable("dkim_reputation_reject", tostring(rep_rejected))
       end
     end
   end
@@ -215,22 +243,20 @@ local function dkim_reputation_idempotent(task, rule)
 end
 
 local function dkim_reputation_postfilter(task, rule)
-  local sym_accepted = task:get_symbol('R_DKIM_ALLOW')
+  local sym_accepted = (task:get_symbol('R_DKIM_ALLOW') or E)[1]
   local accept_adjustment = task:get_mempool():get_variable("dkim_reputation_accept")
+  local cfg = rule.selector.config or E
 
-  if sym_accepted and accept_adjustment then
-    local final_adjustment = rule.config.max_accept_adjustment *
-        rspamd_util.tanh(tonumber(accept_adjustment))
-    task:adjust_result('R_DKIM_ALLOW', sym_accepted.score * final_adjustment)
-  end
+  if sym_accepted and sym_accepted.score and
+      accept_adjustment and type(cfg.max_accept_adjustment) == 'number' then
+    local final_adjustment = cfg.max_accept_adjustment *
+        rspamd_util.tanh(tonumber(accept_adjustment) or 0)
+    lua_util.debugm(N, task, "adjust DKIM_ALLOW: " ..
+        "cfg.max_accept_adjustment=%s accept_adjustment=%s final_adjustment=%s sym_accepted.score=%s",
+        cfg.max_accept_adjustment, accept_adjustment, final_adjustment,
+        sym_accepted.score)
 
-  local sym_rejected = task:get_symbol('R_DKIM_REJECT')
-  local reject_adjustment = task:get_mempool():get_variable("dkim_reputation_reject")
-
-  if sym_rejected and reject_adjustment then
-    local final_adjustment = rule.config.max_reject_adjustment *
-        rspamd_util.tanh(tonumber(reject_adjustment))
-    task:adjust_result('R_DKIM_REJECT', sym_rejected.score * final_adjustment)
+    task:adjust_result('R_DKIM_ALLOW', sym_accepted.score + final_adjustment)
   end
 end
 
@@ -243,7 +269,6 @@ local dkim_selector = {
     outbound = true,
     inbound = true,
     max_accept_adjustment = 2.0, -- How to adjust accepted DKIM score
-    max_reject_adjustment = 3.0 -- How to adjust rejected DKIM score
   },
   dependencies = {"DKIM_TRACE"},
   filter = dkim_reputation_filter, -- used to get scores
@@ -286,30 +311,44 @@ end
 
 local function url_reputation_filter(task, rule)
   local requests = gen_url_queries(task, rule)
+  local url_keys = lua_util.keys(requests)
+  local requests_left = #url_keys
   local results = {}
-  local nchecked = 0
 
   local function indexed_tokens_cb(err, index, values)
-    nchecked = nchecked + 1
+    requests_left = requests_left - 1
 
     if values then
       results[index] = values
     end
 
-    if nchecked == #requests then
+    if requests_left == 0 then
       -- Check the url with maximum hits
       local mhits = 0
-      for k,_ in pairs(results) do
-        if requests[k][2] > mhits then
-          mhits = requests[k][2]
+
+      for i,res in ipairs(results) do
+        local req = requests[i]
+        if req then
+          local hits = tonumber(res[1])
+          if hits > mhits then
+            mhits = hits
+          end
+        else
+          rspamd_logger.warnx(task, "cannot find the requested response for a request: %s (%s requests noticed)",
+              i, #requests)
         end
       end
 
       if mhits > 0 then
         local score = 0
-        for k,v in pairs(results) do
-          score = score + generic_reputation_calc(v, rule,
-              requests[k][2] / mhits, task)
+        for i,res in pairs(results) do
+          local req = requests[i]
+          if req then
+            local url_score = generic_reputation_calc(res, rule,
+                req[2] / mhits, task)
+            lua_util.debugm(N, task, "score for url %s is %s, score=%s", req[1], url_score, score)
+            score = score + url_score
+          end
         end
 
         if math.abs(score) > 1e-3 then
@@ -360,7 +399,7 @@ local function ip_reputation_init(rule)
   local cfg = rule.selector.config
 
   if cfg.asn_cc_whitelist then
-    cfg.asn_cc_whitelist = rspamd_map_add('reputation',
+    cfg.asn_cc_whitelist = lua_maps.map_add('reputation',
       'asn_cc_whitelist',
       'map',
       'IP score whitelisted ASNs/countries')
@@ -599,8 +638,6 @@ local spf_selector = {
     max_score = nil,
     outbound = true,
     inbound = true,
-    max_accept_adjustment = 2.0, -- How to adjust accepted DKIM score
-    max_reject_adjustment = 3.0 -- How to adjust rejected DKIM score
   },
   dependencies = {"R_SPF_ALLOW"},
   filter = spf_reputation_filter, -- used to get scores
@@ -1254,6 +1291,7 @@ local function parse_rule(name, tbl)
     name = rule.symbol,
     type = rule_type,
     callback = callback_gen(reputation_filter_cb, rule),
+    augmentations = {string.format("timeout=%f", redis_params.timeout or 0.0)},
   }
 
   if rule.selector.config.split_symbols then
@@ -1280,8 +1318,9 @@ local function parse_rule(name, tbl)
     rspamd_config:register_symbol{
       name = rule.symbol .. '_POST',
       type = 'postfilter',
-      flags = 'nostat',
+      flags = 'nostat,explicit_disable,ignore_passthrough',
       callback = callback_gen(reputation_postfilter_cb, rule),
+      augmentations = {string.format("timeout=%f", redis_params.timeout or 0.0)},
     }
   end
 
@@ -1290,7 +1329,9 @@ local function parse_rule(name, tbl)
     rspamd_config:register_symbol{
       name = rule.symbol .. '_IDEMPOTENT',
       type = 'idempotent',
+      flags = 'explicit_disable,ignore_passthrough',
       callback = callback_gen(reputation_idempotent_cb, rule),
+      augmentations = {string.format("timeout=%f", redis_params.timeout or 0.0)},
     }
   end
 
