@@ -1,5 +1,5 @@
 --[[
-Copyright (c) 2017, Vsevolod Stakhov <vsevolod@highsecure.ru>
+Copyright (c) 2022, Vsevolod Stakhov <vsevolod@rspamd.com>
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -51,6 +51,7 @@ local settings = {
   max_size = 10 * 1024, -- maximum body to process
   user_agent = default_ua,
   redirector_symbol = nil, -- insert symbol if redirected url has been found
+  redirector_symbol_nested = "URL_REDIRECTOR_NESTED", -- insert symbol if nested limit has been reached
   redirectors_only = true, -- follow merely redirectors
   top_urls_key = 'rdr:top_urls', -- key for top urls
   top_urls_count = 200, -- how many top urls to save
@@ -74,7 +75,7 @@ local function adjust_url(task, orig_url, redir_url)
   end
 end
 
-local function cache_url(task, orig_url, url, key, param)
+local function cache_url(task, orig_url, url, key, prefix)
   -- String representation
   local str_orig_url = tostring(orig_url)
   local str_url = tostring(url)
@@ -140,6 +141,10 @@ local function cache_url(task, orig_url, url, key, param)
     end
   end
 
+  if prefix then
+    -- Save url with prefix
+    str_url = string.format('^%s:%s', prefix, str_url)
+  end
   local ret,conn,_ = lua_redis.redis_make_request(task,
     redis_params, -- connect params
     key, -- hash key
@@ -156,6 +161,16 @@ local function cache_url(task, orig_url, url, key, param)
   end
 end
 
+-- Reduce length of a string to a given length (16 by default)
+local function maybe_trim_url(url, limit)
+  if not limit then limit = 16 end
+  if #url > limit then
+    return string.sub(url, 1, limit) .. '...'
+  else
+    return url
+  end
+end
+
 -- Resolve maybe cached url
 -- Orig url is the original url object
 -- url should be a new url object...
@@ -165,11 +180,21 @@ local function resolve_cached(task, orig_url, url, key, ntries)
       -- We cannot resolve more, stop
       rspamd_logger.debugm(N, task, 'cannot get more requests to resolve %s, stop on %s after %s attempts',
         orig_url, url, ntries)
-      cache_url(task, orig_url, url, key)
+      cache_url(task, orig_url, url, key, 'nested')
+      task:insert_result(settings.redirector_symbol_nested, 1.0,
+          string.format('%s->%s:%d', maybe_trim_url(orig_url), maybe_trim_url(url), ntries))
 
       return
     end
 
+    local redirection_codes = {
+      [301] = true, -- moved permanently
+      [302] = true, -- found
+      [303] = true, -- see other
+      [307] = true, -- temporary redirect
+      [308] = true, -- permanent redirect
+    }
+
     local function http_callback(err, code, _, headers)
       if err then
         rspamd_logger.infox(task, 'found redirect error from %s to %s, err message: %s',
@@ -187,7 +212,7 @@ local function resolve_cached(task, orig_url, url, key, ntries)
 
           cache_url(task, orig_url, url, key)
 
-        elseif code == 301 or code == 302 then
+        elseif redirection_codes[code] then
           local loc = headers['location']
           local redir_url
           if loc then
@@ -250,6 +275,15 @@ local function resolve_cached(task, orig_url, url, key, ntries)
           -- Got cached result
           rspamd_logger.debugm(N, task, 'found cached redirect from %s to %s',
             url, data)
+          if data.sub(1, 1) == '^' then
+            -- Prefixed url stored
+            local prefix, new_url = data:match('^%^(%a+):(.+)$')
+            if prefix == 'nested' then
+              task:insert_result(settings.redirector_symbol_nested, 1.0,
+                  string.format('%s->%s:cached', maybe_trim_url(url), maybe_trim_url(new_url)))
+            end
+            data = new_url
+          end
           if data ~= tostring(orig_url) then
             adjust_url(task, orig_url, data)
           end
@@ -316,6 +350,7 @@ local function url_redirector_handler(task)
       end
     end,
     no_cache = true,
+    need_content = true,
   })
 
   if sp_urls then
@@ -356,7 +391,17 @@ if opts then
       local id = rspamd_config:register_symbol{
         name = 'URL_REDIRECTOR_CHECK',
         type = 'callback,prefilter',
+        priority = lua_util.symbols_priorities.medium,
         callback = url_redirector_handler,
+        -- In fact, the real timeout is nested_limit * timeout...
+        augmentations = {string.format("timeout=%f", settings.timeout)}
+      }
+
+      rspamd_config:register_symbol{
+        name = settings.redirector_symbol_nested,
+        type = 'virtual',
+        parent = id,
+        score = 0,
       }
 
       if settings.redirector_symbol then
